Yuio By Example
===============

A simple step-by-step guide that will walk you through Yuio's essentials.

.. tip::

    All GIFs in this tutorial are generated automatically on documentation build.
    If you see anything strange, `open an issue`__!

    __ https://github.com/taminomara/yuio/issues

.. toctree::
    :maxdepth: 2

    hello_world
    interactive_things
    parsers
    configs
    cli
